package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Mar 3, 2026
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Schema returns the JSON schema for EditInput with translated descriptions
type EditInput struct {
Path string `json:"path"`
Search string `json:"search"`
Replace string `json:"replace"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.